.. :changelog:

Release History
---------------

0.1.1
++++++++++++++++++

- Added more websources, twitter handles & RSS feeds
- Added tests
- Restructured the package

0.1.0
++++++++++++++++++

- Initial release
